#include <tremor/ivorbisfile.h>
#include <cassert>
#include <cstdio>
#include <string>

std::string PlatformMakeAbsPath( const char* path )
{
	assert( path != NULL );
	std::string ans = [[[NSBundle mainBundle] bundlePath] UTF8String];
	
	if( path[0] != '/' )
	{
		ans += "/";
	}
	ans += path;
	
	return ans;
}

int main (int argc, char * const argv[]) 
{
	static const unsigned int bufferLength = 8192;
	char buffer[bufferLength];
	
	FILE* a220 = fopen( PlatformMakeAbsPath("A220.ogg").c_str(), "r" );
	assert( a220 != NULL );
	OggVorbis_File* vf = new OggVorbis_File();
	int result = ov_open( a220, vf,  NULL, 0 );
	assert( result == 0 );
	
	//i know A220.ogg is mono with a frequency of 220
	vorbis_info* info = ov_info( vf, -1 );
	assert( info != NULL );
	assert( info->channels == 1 );
	assert( info->rate == 44100 );
	
	//read data from the ogg file 8192 bytes at a time
	bool dataLeft = true;
	while( dataLeft )
	{
		unsigned int amtDesired = bufferLength;
		char* currBufferPtr = buffer;
		
		while( amtDesired > 0 )
		{
			int bitStream;
			int amtRead = ov_read( vf, currBufferPtr, amtDesired, &bitStream );
			assert( amtRead >= 0 );
			
			if( amtRead == 0 )
			{
				dataLeft = false;
				break;
			}
			
			assert( amtRead <= amtDesired );
			amtDesired -= amtRead;
			currBufferPtr = currBufferPtr + amtRead;
		}
	}
	
	assert( ov_pcm_tell( vf ) < ov_pcm_total( vf, -1) );
}